package com.izouma.awesomeadmin.dao;

import com.izouma.awesomeadmin.model.MemberCoin;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;


/**
*  Dao接口
*/
@Repository("com.izouma.awesomeadmin.dao.MemberCoinMapper")
public interface MemberCoinMapper{

    int deleteByPrimaryKey(Integer id);

    int insertSelective(MemberCoin record);

    MemberCoin selectByPrimaryKey(Integer id);

    int updateByPrimaryKeySelective(MemberCoin record);

    List<MemberCoin> queryAllMemberCoin(MemberCoin record);

    List<MemberCoin> queryMemberCoinByPage(Map<String, Object> parameter);

    int delete(String id);

    MemberCoin queryMemberCoin(MemberCoin record);

    List<MemberCoin> query(MemberCoin record);
}

